# ndbounds

Toolbox for handling n-dimensional bounds.

## n-Dimensional Bounds

The basic idea of this format is to combine methods for working with boundaries in
* 1D (e.g. onset & end of waveforms),
* 2D (e.g. bounding boxes in an image) or
* any higher nD case.